===============================
Djeff
===============================

.. image:: https://img.shields.io/travis/lightstrike/djeff.svg
        :target: https://travis-ci.org/lightstrike/djeff

.. image:: https://img.shields.io/pypi/v/djeff.svg
        :target: https://pypi.python.org/pypi/djeff


Add silent D's to all the things (or just the things you want)

* Free software: ISC license
* Documentation: https://djeff.readthedocs.org.

Features
--------

* TODO
